<?php

declare(strict_types = 1);

namespace Drupal\brightcove\Services;

use Drupal\brightcove\Module;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Handles module specific settings.
 */
final class Settings implements SettingsInterface {

  /**
   * Settings storage.
   *
   * @var \Drupal\Core\Config\Config
   */
  private $settings;

  /**
   * Initializes a settings handler service.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Configuration factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->settings = $config_factory->getEditable(Module::NAME . '.settings');
  }

  /**
   * Helper function for set a setting.
   *
   * @param string $key
   *   The key of the setting.
   * @param mixed $value
   *   The value of the setting.
   */
  private function set(string $key, $value): void {
    $this->settings->set($key, $value)->save();
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultApiClientId(): string {
    return $this->settings->get(static::DEFAULT_API_CLIENT);
  }

  /**
   * {@inheritdoc}
   */
  public function getMarkedFieldExpiry(): int {
    return $this->settings->get(static::INGESTION_MARKED_FIELD_EXPIRY);
  }

  /**
   * {@inheritdoc}
   */
  public function getNotificationCallbackExpirationTime(): ?int {
    return $this->settings->get(static::NOTIFICATION_CALLBACK_EXPIRATION_TIME);
  }

  /**
   * {@inheritdoc}
   */
  public function isCronDisabled(): bool {
    return $this->settings->get(static::DISABLE_CRON);
  }

  /**
   * {@inheritdoc}
   */
  public function setDefaultApiClientId(string $api_client_id): void {
    $this->set(static::DEFAULT_API_CLIENT, $api_client_id);
  }

  /**
   * {@inheritdoc}
   */
  public function setCronDisabled(bool $is_disabled): void {
    $this->set(static::DISABLE_CRON, $is_disabled);
  }

  /**
   * {@inheritdoc}
   */
  public function setMarkedFieldExpiry(int $seconds): void {
    $this->set(static::INGESTION_MARKED_FIELD_EXPIRY, $seconds);
  }

}
